Trait massa_event_cache::worker::EventCacheManager
source · pub trait EventCacheManager {
// Required method
fn stop(&mut self);
}Expand description
Event cache manager trait used to stop the event cache thread
pub trait EventCacheManager {
// Required method
fn stop(&mut self);
}Event cache manager trait used to stop the event cache thread